@@ -77,7 +77,7 @@ class TahrirDatabase(object):
         """
 
         session = scoped_session(self.session_maker)
-        badge_id = name.lower()
+        badge_id = name.lower().replace(" ", "-")
 
         if not self.badge_exists(badge_id):
             new_badge = Badge(
@@ -225,7 +225,7 @@ class TahrirDatabase(object):
 
         session = scoped_session(self.session_maker)
         return session.query(Issuer)\
-                .filter_by(name=name, origin=origin).one()
+                .filter_by(name=name, origin=origin).one().id
 
     def get_assertions_by_email(self, person_email):
         """
